@@ -209,7 +209,13 @@ void DockView::init()
     connect(corona(), &Plasma::Corona::availableScreenRectChanged, this, &DockView::availableScreenRectChanged);
 
     connect(this, &DockView::behaveAsPlasmaPanelChanged, this, &DockView::syncGeometry);
-    connect(this, &DockView::drawShadowsChanged, this, &DockView::syncGeometry);
+    connect(this, &DockView::drawShadowsChanged, this, [&]() {
+        if (!m_behaveAsPlasmaPanel) {
+            syncGeometry();
+        } else {
+            updateEnabledBorders();
+        }
+    });
     connect(this, &DockView::maxLengthChanged, this, &DockView::syncGeometry);
     connect(this, &DockView::offsetChanged, this, &DockView::syncGeometry);
     connect(this, &DockView::alignmentChanged, this, &DockView::updateEnabledBorders);
@@ -444,27 +450,31 @@ bool DockView::setCurrentScreen(const QString id)
 //! dock its first origin screen is stored and that way when
 //! that screen is reconnected the dock will return to its original
 //! place
-void DockView::setScreenToFollow(QScreen *screen, bool updateScreenId)
+void DockView::setScreenToFollow(QScreen *scr, bool updateScreenId)
 {
-    if (!screen || m_screenToFollow == screen) {
+    if (!scr || (scr && (m_screenToFollow == scr) && (screen() == scr))) {
         return;
     }
 
-    m_screenToFollow = screen;
+    qDebug() << "setScreenToFollow() called for screen:" << scr->name() << " update:" << updateScreenId;
+
+    m_screenToFollow = scr;
 
     if (updateScreenId) {
-        m_screenToFollowId = screen->name();
+        m_screenToFollowId = scr->name();
     }
 
     qDebug() << "adapting to screen...";
-    setScreen(screen);
+    setScreen(scr);
 
     if (this->containment())
         this->containment()->reactToScreenChange();
 
-    connect(screen, &QScreen::geometryChanged, this, &DockView::screenGeometryChanged);
+    connect(scr, &QScreen::geometryChanged, this, &DockView::screenGeometryChanged);
     syncGeometry();
     updateAbsDockGeometry(true);
+    qDebug() << "setScreenToFollow() ended...";
+
     emit screenGeometryChanged();
     emit currentScreenChanged();
 }
@@ -477,6 +487,7 @@ void DockView::reconsiderScreen()
         return;
     }
 
+    qDebug() << "reconsiderScreen() called...";
     qDebug() << "  Delayer  ";
 
     foreach (auto scr, qGuiApp->screens()) {
@@ -497,12 +508,13 @@ void DockView::reconsiderScreen()
 
     //! 1.a primary dock must be always on the primary screen
     if (m_onPrimary && (m_screenToFollowId != qGuiApp->primaryScreen()->name()
-                        || m_screenToFollow != qGuiApp->primaryScreen())) {
+                        || m_screenToFollow != qGuiApp->primaryScreen()
+                        || screen() != qGuiApp->primaryScreen())) {
         using Plasma::Types;
         QList<Types::Location> edges{Types::BottomEdge, Types::LeftEdge,
                                      Types::TopEdge, Types::RightEdge};
 
-        edges = m_managedLayout ? m_managedLayout->freeEdges(qGuiApp->primaryScreen()) : edges;
+        edges = m_managedLayout ? m_managedLayout->availableEdgesForView(qGuiApp->primaryScreen(), this) : edges;
 
         //change to primary screen only if the specific edge is free
         qDebug() << "updating the primary screen for dock...";
@@ -513,7 +525,6 @@ void DockView::reconsiderScreen()
             //! case 1
             qDebug() << "reached case 1: of updating dock primary screen...";
             setScreenToFollow(qGuiApp->primaryScreen());
-            syncGeometry();
         }
     } else if (!m_onPrimary) {
         //! 2.an explicit dock must be always on the correct associated screen
@@ -523,12 +534,14 @@ void DockView::reconsiderScreen()
             if (scr && scr->name() == m_screenToFollowId) {
                 qDebug() << "reached case 2: updating the explicit screen for dock...";
                 setScreenToFollow(scr);
-                syncGeometry();
                 break;
             }
         }
     }
 
+    syncGeometry();
+    qDebug() << "reconsiderScreen() ended...";
+
     emit docksCountChanged();
 }
 
@@ -886,11 +899,20 @@ inline void DockView::syncGeometry()
 
     bool found{false};
 
+    qDebug() << "syncGeometry() called...";
+
     //! before updating the positioning and geometry of the dock
     //! we make sure that the dock is at the correct screen
     if (this->screen() != m_screenToFollow) {
-        qDebug() << "Sync Geometry screens inconsistent!!!!";
-        m_screenSyncTimer.start();
+        qDebug() << "Sync Geometry screens inconsistent!!!! ";
+
+        if (m_screenToFollow) {
+            qDebug() << "Sync Geometry screens inconsistent for m_screenToFollow:" << m_screenToFollow->name() << " dock screen:" << screen()->name();
+        }
+
+        if (!m_screenSyncTimer.isActive()) {
+            m_screenSyncTimer.start();
+        }
     } else {
         found = true;
     }
@@ -941,8 +963,12 @@ inline void DockView::syncGeometry()
         updateEnabledBorders();
         resizeWindow(availableScreenRect);
         updatePosition(availableScreenRect);
+
+        qDebug() << "syncGeometry() calculations for screen: " << screen()->name() << " _ " << screen()->geometry();
     }
 
+    qDebug() << "syncGeometry() ended...";
+
     // qDebug() << "dock geometry:" << qRectToStr(geometry());
 }
 
