@@ -16,8 +16,8 @@
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
-#ifndef PLASMA_PANELSHADOWS_H
-#define PLASMA_PANELSHADOWS_H
+#ifndef PANELSHADOWS_P_H
+#define PANELSHADOWS_P_H
 
 #include <QSet>
 
@@ -30,7 +30,7 @@ class PanelShadows : public Plasma::Svg
     Q_OBJECT
 
 public:
-    explicit PanelShadows(QObject *parent = 0, const QString &prefix = QStringLiteral("widgets/panel-background"));
+    explicit PanelShadows(QObject *parent = nullptr, const QString &prefix = QStringLiteral("widgets/panel-background"));
     ~PanelShadows() override;
 
     static PanelShadows *self();
@@ -51,3 +51,4 @@ private:
 };
 
 #endif
+
