@@ -31,11 +31,13 @@ namespace Latte {
 
 //! This class is responsible to import/export configurations
 //! and of course to import old configuration to new architecture
-class Importer : public QObject {
+class Importer : public QObject
+{
     Q_OBJECT
 
 public:
-    enum LatteFileVersion {
+    enum LatteFileVersion
+    {
         UnknownFileType = -1,
         LayoutVersion1 = 0,
         ConfigVersion1 = 1,
