@@ -41,11 +41,14 @@ void DockPackage::initPackage(KPackage::Package *package)
     auto fallback = KPackage::PackageLoader::self()->loadPackage("Plasma/Shell", "org.kde.plasma.desktop");
     package->setDefaultPackageRoot(QStringLiteral("plasma/shells/"));
     package->setPath("org.kde.latte.shell");
+    package->addFileDefinition("defaults", QStringLiteral("defaults"), i18n("Latte Dock defaults"));
     package->addFileDefinition("lattedockui", QStringLiteral("views/Panel.qml"), i18n("Latte Dock panel"));
     //Configuration
     package->addFileDefinition("lattedockconfigurationui", QStringLiteral("configuration/LatteDockConfiguration.qml"), i18n("Dock configuration UI"));
+    package->addFileDefinition("lattedocksecondaryconfigurationui", QStringLiteral("configuration/LatteDockSecondaryConfiguration.qml"), i18n("Dock secondary configuration UI"));
     package->addFileDefinition("configmodel", QStringLiteral("configuration/config.qml"), i18n("Config model"));
-    package->addFileDefinition("trademark", QStringLiteral("images/trademark.svg"), i18n("Latte Trademark"));
+    package->addFileDefinition("splitter", QStringLiteral("images/splitter.svgz"), i18n("Splitter"));
+    package->addFileDefinition("trademark", QStringLiteral("images/trademark.svgz"), i18n("Latte Trademark"));
     package->addFileDefinition("infoviewui", QStringLiteral("views/InfoView.qml"), i18n("Info View Window"));
 
     package->addFileDefinition("layout1", QStringLiteral("layouts/Default.latterc"), i18n("default layout file"));
@@ -57,8 +60,7 @@ void DockPackage::initPackage(KPackage::Package *package)
     package->addFileDefinition("preset2", QStringLiteral("presets/Plasma.layout.latte"), i18n("plasma preset file"));
     package->addFileDefinition("preset3", QStringLiteral("presets/Unity.layout.latte"), i18n("unity preset file"));
     package->addFileDefinition("preset4", QStringLiteral("presets/Extended.layout.latte"), i18n("extended preset file"));
-
-    package->addFileDefinition("separator0", QStringLiteral("controls/latte-separator.desktop"), i18n("tasks plasmoid separator"));
+    package->addFileDefinition("preset10", QStringLiteral("presets/multiple-layouts_hidden.layout.latte"), i18n("multiple layouts hidden file"));
 
     package->setFallbackPackage(fallback);
     qDebug() << "package is valid" << package->isValid();
