@@ -664,7 +664,8 @@ void SettingsDialog::requestImagesDialog(int row)
 
     QString background = m_model->data(m_model->index(row, COLORCOLUMN), Qt::BackgroundRole).toString();
 
-    if (background.startsWith("/")) {
+    if (background.startsWith("/") && QFileInfo(background).exists()) {
+        dialog.setDirectory(QFileInfo(background).absolutePath());
         dialog.selectFile(background);
     }
 
@@ -850,6 +851,21 @@ void SettingsDialog::loadSettings()
         }
     }
 
+
+    //! Check Multiple Layouts Integrity
+    /*if (m_corona->layoutManager()->memoryUsage() == Dock::MultipleLayouts) {
+        m_corona->layoutManager()->syncActiveLayoutsToOriginalFiles();
+
+        QString multipleLayoutPath = QDir::homePath() + "/.config/latte/" + Layout::MultipleLayoutsName + ".layout.latte";
+        Layout multipleHiddenLayouts(this, multipleLayoutPath, "Multiple Layouts File");
+
+        if (multipleHiddenLayouts.layoutIsBroken()) {
+            qDebug() << "Intergrity Error ::: Multiple Layouts Hidden file is broken!!!!";
+            brokenLayouts.append(multipleHiddenLayouts.name());
+        }
+    }*/
+
+
     recalculateAvailableActivities();
 
     m_model->setHorizontalHeaderItem(IDCOLUMN, new QStandardItem(QString("#path")));
